@@ -28,6 +28,18 @@ use db\param;
 use db\clause;
 use db\selectHelper;
 
+use conf\conf;
+
+use geo\map;
+use geo\point;
+use geo\track;
+use geo\marker;
+
+use template\block;
+use template\template;
+
+use photo\collection;
+
 /**
  * A class corresponding to the photos table.
  *
@@ -41,7 +53,12 @@ class photo extends zophTable {
     /** @var array List of primary keys */
     protected static $primaryKeys=array("photo_id");
     /** @var array Fields that may not be empty */
-    protected static $notNull=array();
+    protected static $notNull=array("time_corr");
+    /** @var array Fields that are integers */
+    protected static $isInteger=array(
+        "photo_id", "width", "height", "size", "photographer_id", "location_id", "time_corr", "level", "mapzoom");
+    /** @var array Fields that are floats */
+    protected static $isFloat=array("lat", "lon");
     /** @var bool keep keys with insert. In most cases the keys are set by the
              db with auto_increment */
     protected static $keepKeys = false;
@@ -77,6 +94,10 @@ class photo extends zophTable {
         }
         $image_path .= $name;
 
+        if (!file_exists($image_path)) {
+            throw new photoNotFoundException($name . " could not be found");
+        }
+
         $mtime = filemtime($image_path);
         $filesize = filesize($image_path);
         $gmt_mtime = gmdate('D, d M Y H:i:s', $mtime) . ' GMT';
@@ -199,6 +220,20 @@ class photo extends zophTable {
         );
     }
 
+    public function update() {
+        if (empty($this->get("time_corr"))) {
+            $this->set("time_corr", 0);
+        }
+        return parent::update();
+    }
+
+    public function insert() {
+        if (empty($this->get("time_corr"))) {
+            $this->set("time_corr", 0);
+        }
+        return parent::insert();
+    }
+
     /**
      * Update photo relations, such as albums, categories, etc.
      * @param array array of variables to update
@@ -381,7 +416,7 @@ class photo extends zophTable {
         $qry->join(array("pp" => "photo_people"), "pp.person_id = p.person_id");
         $distinct=true;
         $qry->addFields(array("person_id"), $distinct);
-        $qry->addFields(array("last_name", "first_name", "called"));
+        $qry->addFields(array("last_name", "first_name", "called", "pp.position"));
 
         $where=new clause("pp.photo_id=:photoid");
 
@@ -563,6 +598,24 @@ class photo extends zophTable {
 
         $file=$this->getFilePath($type);
 
+        if (!file_exists($file)) {
+            switch ($type) {
+            case MID_PREFIX:
+                $size="width='" . MID_SIZE . "'";
+                break;
+            case THUMB_PREFIX:
+                $size="width='" . THUMB_SIZE . "'";
+                break;
+            default:
+                $size="";
+            }
+            return new block("img", array(
+                "src"   => template::getImage("notfound.png"),
+                "class" => $type,
+                "size"  => $size,
+                "alt"   => "file not found"
+            ));
+        }
         list($width, $height, $filetype, $size)=getimagesize($file);
 
         $alt = e($this->get("title"));
@@ -793,7 +846,7 @@ class photo extends zophTable {
         }
 
         // make a system call to convert or jpegtran to do the rotation.
-        while (list($file, $tmp_file) = each($images)) {
+        foreach ($images as $file => $tmp_file) {
             if (!file_exists($file)) {
                 throw new FileNotFoundException("Could not find " . $file);
             }
@@ -1114,9 +1167,9 @@ class photo extends zophTable {
      */
     public function exifToHTML() {
         if (exif_imagetype($this->getFilePath())==IMAGETYPE_JPEG) {
-            $exif=read_exif_data($this->getFilePath());
+            $exif=exif_read_data($this->getFilePath());
             if ($exif) {
-                $return="<dl class='allexif'>\n";
+                $return="<dl id='allexif'>\n";
 
                 foreach ($exif as $key => $value) {
                     if (!is_array($value)) {
@@ -1163,8 +1216,8 @@ class photo extends zophTable {
         } else {
             $html="<h2>" . e($file) . "<\/h2>";
         }
-        $html.=$this->getThumbnailLink()->toStringNoEnter() .
-          "<p><small>" .
+        $html.=str_replace("\n", "", $this->getThumbnailLink());
+        $html.="<p><small>" .
           $this->get("date") . " " . $this->get("time") . "<br>";
         if ($this->photographer) {
             $html.=translate("by", 0) . " " . $this->photographer->getLink(1) . "<br>";
@@ -1179,7 +1232,7 @@ class photo extends zophTable {
      * @return marker instance of marker class
      */
     public function getMarker($icon="geo-photo") {
-        $marker=map::getMarkerFromObj($this, $icon);
+        $marker=marker::getFromObj($this, $icon);
         if (!$marker instanceof marker) {
             $loc=$this->location;
             if ($loc instanceof place) {
@@ -1618,7 +1671,7 @@ class photo extends zophTable {
      * @param array Array of photos
      * @return int size in bytes
      */
-    public static function getFilesize(array $photos) {
+    public static function getFilesize(collection $photos) {
         $bytes=0;
         foreach ($photos as $photo) {
             $photo->lookup();
