@@ -22,6 +22,9 @@
  * @author Jeroen Roos
  */
 
+use conf\conf;
+use template\template;
+
 require_once "include.inc.php";
 
 $title = translate("E-Mail Photo");
@@ -182,7 +185,7 @@ if ($found && $_action == "compose") {
     $ea = $photo->getEmailArray();
 
     if ($ea) {
-        while (list($name, $value) = each($ea)) {
+        foreach ($ea as $name => $value) {
             if ($name && $value) {
                 $body .= "$name: $value\r\n";
             }
