@@ -21,6 +21,7 @@
  * @author Jason Geiger
  * @author Jeroen Roos
  */
+use conf\conf;
 require_once "include.inc.php";
 
 if (!$user->isAdmin()) {
@@ -117,9 +118,9 @@ if ($_action == "notify") {
         $albums = getNewer($u, $date);
 
         $album_list = array();
-        while (list($id, $album) = each($albums)) {
+        foreach ($album as $id => $album) {
             $album_path = '';
-            $ancestors = $album->get_ancestors();
+            $ancestors = $album->getAncestors();
             if ($ancestors) {
                 while ($parent = array_pop($ancestors)) {
                     $album_path .= $parent->get("album") .  " > ";
