@@ -22,17 +22,19 @@
  * @author Jeroen Roos
  */
 
+use conf\conf;
+
+use photo\collection;
+
+use template\template;
+use template\block;
+
+use web\request;
+
 require_once "include.inc.php";
 $photo_id = getvar("photo_id");
 $_off = getvar("_off");
 
-/*
-Before deciding to include the Prev and Next links, it was as
-simple as this.  But now we go through get_photos().
-
-$photo = new photo($photo_id);
-*/
-
 $_qs=getvar("_qs");
 
 $qs = preg_replace('/_crumb=\d+&?/', '', $_SERVER["QUERY_STRING"]);
@@ -49,6 +51,7 @@ if (empty($qs)) {
 
 $prev_link="";
 $next_link="";
+$up_link="";
 $act="";
 $num_photos=0;
 if ($photo_id) {
@@ -56,15 +59,15 @@ if ($photo_id) {
     $photo = new photo($photo_id);
 } else {
     // for display
-    if (!$_off)  { $_off = 0; }
+    if (!$_off)  {
+        $_off = 0;
+    }
     $offset = $_off;
 
-    $num_photos = get_photos($request_vars, $offset, 1, $thumbnails, $user);
-
-    $num_thumbnails = sizeof($thumbnails);
-
-    if  ($num_thumbnails) {
-        $photo = $thumbnails[0];
+    $photoCollection = collection::createFromRequest(request::create());
+    $photos=$photoCollection->subset($offset, 1);
+    if ($photos) {
+        $photo = $photos->shift();
         $photo_id = $photo->getId();
         if (isset($_action) && !$_action=="") {
             $act="_action=" . $_action . "&";
@@ -72,15 +75,17 @@ if ($photo_id) {
 
         if ($offset > 0) {
             $newoffset = $offset - 1;
-            $prev_link = "<a href=\"" . $_SERVER["PHP_SELF"] . "?" . $act .
-                htmlentities(str_replace("_off=$offset", "_off=$newoffset", $qs)) . "\">" .
+            $prev_url=$_SERVER["PHP_SELF"] . "?" . $act .
+                htmlentities(str_replace("_off=$offset", "_off=$newoffset", $qs));
+            $prev_link = "<a href=\"" . $prev_url . "\">" .
                 translate("Prev") . "</a>";
         }
 
-        if ($offset + 1 < $num_photos) {
+        if ($offset + 1 < sizeof($photoCollection)) {
             $newoffset = $offset + 1;
-            $next_link = "<a href=\"" . $_SERVER["PHP_SELF"] . "?" . $act .
-                htmlentities(str_replace("_off=$offset", "_off=$newoffset", $qs)) . "\">" .
+            $next_url = $_SERVER["PHP_SELF"] . "?" . $act .
+                htmlentities(str_replace("_off=$offset", "_off=$newoffset", $qs));
+            $next_link = "<a href=\"" . $next_url . "\">" .
                 translate("Next") . "</a>";
         }
     } else {
@@ -95,9 +100,6 @@ if (!$user->isAdmin()) {
 if (isset($offset)) {
     $ignore = array("_off", "_action");
 
-    # To fix bug #1259152:
-    # get $_off, round it down to a multiple of cols x rows.
-
     $_cols = (int) getvar("_cols");
     $_rows = (int) getvar("_rows");
     $_off = (int) getvar("_off");
@@ -347,20 +349,18 @@ if ($action != "insert" && !$found) {
         <?php
     }
     ?>
-    <div class="prev"><?php echo $prev_link ? "[ $prev_link ]" : "&nbsp;" ?></div>
-    <div class="photohdr">
-    <?php
-    if (isset($up_link)) {
-        ?>
-        [ <?php echo $up_link ?> ]<br>
-        <?php
-    }
-    ?>
+    <nav class="photohdr">
+        <ul>
+            <li class="prev"><?php echo $prev_link ?></li>
+            <li class="up"><?php echo $up_link ?></li>
+            <li class="next"><?php echo $next_link ?></li>
+        </ul>
+    </nav>
+    <div class="photodata">
         <?php echo $photo->getFullsizeLink($photo->get("name")) ?> :
         <?php echo $photo->get("width") ?> x <?php echo $photo->get("height") ?>,
         <?php echo $photo->get("size") ?> <?php echo translate("bytes") ?>
     </div>
-    <div class="next"><?php echo $next_link ? "[ $next_link ]" : "&nbsp;" ?></div>
     <ul class="tabs">
     <?php
     if (conf::get("share.enable") && ($user->isAdmin() || $user->get("allow_share"))) {
@@ -489,6 +489,7 @@ if ($action != "insert" && !$found) {
     }
     ?>
     <br>
+    </div>
     <?php
 } else if ($action == "confirm") {
     ?>
@@ -498,14 +499,16 @@ if ($action != "insert" && !$found) {
     echo create_actionlinks($actionlinks);
     echo sprintf(translate("Confirm deletion of '%s'"), $photo->get("name"));
     echo $photo->getImageTag(MID_PREFIX);
+    ?>
+    </div>
+<?php
 } else {
     require_once "edit_photo.inc.php";
 }
 ?>
-</div>
 <?php
 if (conf::get("maps.provider") && ($_action=="display" || $_action=="edit" || $_action==="")) {
-    $map=new map();
+    $map=new geo\map();
 
     if ($_action == "edit") {
         $map->setEditable();
